pybottrader.indicators._indicators API documentation

# pybottrader.indicators._indicators

Financial indicators for streaming data implemented in C++

class IndicatorDouble(pybind11_builtins.pybind11_object):
IndicatorDouble()

__init__(self: pybottrader.indicators._indicators.IndicatorDouble, mem_size: int = 1) -> None

def push(unknown):

push(self: pybottrader.indicators._indicators.IndicatorDouble, arg0: float) -> None

def get(unknown):

get(self: pybottrader.indicators._indicators.IndicatorDouble, key: int = 0) -> float

class IndicatorMACDResult(pybind11_builtins.pybind11_object):
IndicatorMACDResult()

__init__(self: pybottrader.indicators._indicators.IndicatorMACDResult, mem_size: int = 1) -> None

def push(unknown):

push(self: pybottrader.indicators._indicators.IndicatorMACDResult, arg0: indicators::MACDResult) -> None

def get(unknown):

get(self: pybottrader.indicators._indicators.IndicatorMACDResult, key: int = 0) -> indicators::MACDResult

class MA(IndicatorDouble):
MA()

__init__(self: pybottrader.indicators._indicators.MA, period: int, mem_size: int = 1) -> None

def update(unknown):

update(self: pybottrader.indicators._indicators.MA, arg0: float) -> float

##### Inherited Members

IndicatorDouble
  push
  get

class EMA(IndicatorDouble):
EMA()

__init__(self: pybottrader.indicators._indicators.EMA, period: int, alpha: float = 2.0, mem_size: int = 1) -> None

def update(unknown):

update(self: pybottrader.indicators._indicators.EMA, arg0: float) -> float

##### Inherited Members

IndicatorDouble
  push
  get

class RSI(IndicatorDouble):
RSI()

__init__(self: pybottrader.indicators._indicators.RSI, period: int = 14, mem_size: int = 1) -> None

def update(unknown):

update(self: pybottrader.indicators._indicators.RSI, open_price: float, close_price: float) -> float

##### Inherited Members

IndicatorDouble
  push
  get

class ROI(IndicatorDouble):
ROI()

__init__(self: pybottrader.indicators._indicators.ROI, mem_size: int = 1) -> None

def update(unknown):

update(self: pybottrader.indicators._indicators.ROI, arg0: float) -> float

##### Inherited Members

IndicatorDouble
  push
  get

class MACDResult(pybind11_builtins.pybind11_object):
MACDResult(*args, **kwargs)
macd

(self: pybottrader.indicators._indicators.MACDResult) -> float

signal

(self: pybottrader.indicators._indicators.MACDResult) -> float

hist

(self: pybottrader.indicators._indicators.MACDResult) -> float

class MACD(IndicatorMACDResult):
MACD()

__init__(self: pybottrader.indicators._indicators.MACD, short_period: int, long_period: int, diff_period: int, mem_size: int = 1) -> None

def update(unknown):

update(self: pybottrader.indicators._indicators.MACD, arg0: float) -> pybottrader.indicators._indicators.MACDResult

##### Inherited Members

IndicatorMACDResult
  push
  get

class ATR(IndicatorDouble):
ATR()

__init__(self: pybottrader.indicators._indicators.ATR, period: int, mem_size: int = 1) -> None

def update(unknown):

update(self: pybottrader.indicators._indicators.ATR, low_price: float, high_price: float, close_price: float) -> float

##### Inherited Members

IndicatorDouble
  push
  get

def roi(unknown):

roi(arg0: float, arg1: float) -> float

Calculate return on investment